# Build with utimensat support. CMake only uses the parts that are
# implemented, but our CI setup doesn't know how to distinguish
%bcond_with allow_utimensat

# Build with jsoncpp support? Currently we don't have it
%bcond_with jsoncpp

# Build with libuv? Currently we don't ship libuv as its own package
%bcond_with libuv

%define major 3
%define minor 7
%define fix 2

Name: cmake
Version: %{major}.%{minor}.%{fix}
Release: 4
License: BSD-3-Clause 
Summary: Open Source Build System
Url: https://cmake.org

BuildRequires: libarchive-devel
BuildRequires: curl-devel
BuildRequires: expat-devel
BuildRequires: bzip2-devel
BuildRequires: xz-devel
BuildRequires: zlib-devel

Source0: https://cmake.org/files/v%{major}.%{minor}/cmake-%{version}.tar.gz

Source1: OS400.cmake
Source2: OS400-GNU-ASM.cmake
Source3: OS400-GNU-C.cmake
Source4: OS400-GNU.cmake
Source5: OS400-GNU-CXX.cmake
Source6: OS400-GNU-Fortran.cmake
Source7: OS400-XL-ASM.cmake
Source8: OS400-XL-C.cmake
Source9: OS400-XL.cmake
Source10: OS400-XL-CXX.cmake
Source11: OS400-XL-Fortran.cmake

Patch0: cmake-disallow-utimensat.patch

%description
CMake is an open-source, cross-platform family of tools designed to build, test
and package software. CMake is used to control the software compilation process
using simple platform and compiler independent configuration files, and generate
native makefiles and workspaces that can be used in the compiler environment of
your choice. The suite of CMake tools were created by Kitware in response to the
need for a powerful, cross-platform build environment for open-source projects
such as ITK and VTK.

%prep
%setup -q

%if %{without allow_utimensat}
%patch0 -p1
%endif

cp \
  %{SOURCE1} \
  %{SOURCE2} \
  %{SOURCE3} \
  %{SOURCE4} \
  %{SOURCE5} \
  %{SOURCE6} \
  %{SOURCE7} \
  %{SOURCE8} \
  %{SOURCE9} \
  %{SOURCE10} \
  %{SOURCE11} \
    Modules/Platform

%build

export CFLAGS="%{optflags} -D_LINUX_SOURCE_COMPAT=1 -pthread"
export CXXFLAGS="%{optflags} -D_LINUX_SOURCE_COMPAT=1 -pthread"
export LDFLAGS="-Wl,-bbigtoc -pthread"
export CC="gcc"
export CXX="g++"

./bootstrap \
  --prefix=%{_prefix} \
  --bindir=bin \
  --datadir=share/cmake-%{major}.%{minor} \
  --docdir=share/doc/cmake-%{major}.%{minor} \
  --mandir=share/man \
  --xdgdatadir=share \
%if %{with jsoncpp} && %{with libuv}
  # When libarchive, jsoncpp, and libuv built
  # add this and remove the rest of the
  # individual --system-* lines, along with
  # this comment
  --system-libs \
%else
  --system-curl \
  --system-expat \
  --system-zlib \
  --system-bzip2 \
  --system-liblzma \
  --system-libarchive \
%if %{with jsoncpp}
  --system-jsoncpp \
%endif
%endif
%if %{with libuv}
  --server \
%else
  --no-server \
  -- \
  -DCMAKE_USE_LIBUV=OFF \
%endif
  # end

%make_build

%install

%make_install

%files
%defattr(-, qsys, *none)

%{_bindir}/ccmake
%{_bindir}/cmake
%{_bindir}/cpack
%{_bindir}/ctest

%{_docdir}/cmake-%{major}.%{minor}

%{_datadir}/aclocal/cmake.m4
%{_datadir}/cmake-%{major}.%{minor}

%changelog
* Wed Dec 04 2019 Kevin Adler <kadler@us.ibm.com> - 3.7.2
- Use SPDX license identifier
- Use bcond_with for conditionals
- Line wrap description to 80 columns
- General cleanup
- Add optflags to CFLAGS an CXXFLAGS since not using configure macro

* Tue Dec 3 2019 Kevin Adler <kadler@us.ibm.com> - 3.7.2
- Prevent using half-implemented utimensat APIs, fixing IBM i 7.2 build

* Wed Jul 25 2018 - Kevin Adler <kadler@us.ibm.com>
- Add AIX and PASE definitions for use in CMakeLists.txt
- Use -bbigtoc instead of -mminimal-toc

* Wed Jul 25 2018 - Kevin Adler <kadler@us.ibm.com>
- cmake needs -pthread for new libstdc++

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- Add BuildRequires
- We have libarchive now, remove conditional flags

* Wed Dec 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove 64-bit GCC script workarounds
- OBJECT_MODE now always set by build and install macros

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Make cmake actually build

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove outdated TODO comments

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use auto dependency resolution instead of requiring pase-libs

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix 64-bit build by setting OBJECT_MODE

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add spec files
